snf-image-creator
=================

Overview
--------

This is snf-image-creator, a command-line tool for creating OS Images to be
used with Synnefo.

It comes in two variants:
* snf-image-creator: A user-friendly dialog-based program
* snf-mkimage: A non-interactive command-line program

Project Page
------------

Please see the [official Synnefo site](http://www.synnefo.org) and the
[latest snf-image-creator docs](http://www.synnefo.org/docs/snf-image-creator/latest/index.html)
for more information.


Copyright and license
=====================

Copyright (C) 2011-2014 GRNET S.A.

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.

